server_client_20141211_175217

### config1 : test_redlining

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.83388113976 sec | 5.08994483948 sec

Error message: server latency too high while sending 10000 integers

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 13.84 | 0.37 | 0.19 | 0.33 | 0.36 | 0.4 | 0.45 | 0.8 | 0.65
qps | 462.00 | 333.67 | 136.00 | 403.00 | 432.50 | 450.20 | 456.10 | 460.82 | 141.83

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0
latency | 1972.35 | 1972.35 | 1972.35 | 1972.35 | 1972.35 | 1972.35 | 1972.35 | 1972.35 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.327
server1-perf | latency | mean lt 0.33 | 0.369403596404
server1-perf | qps | mean lt 7.0 | 333.666666667
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 1972.352
client1-perf | latency | mean lt 35.0 | 1972.352
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None